@@ -1,15 +1,18 @@
 ''' Audio file info computed by soxi.
 '''
-from .log import logger
-
 import os
+from numbers import Number
+from pathlib import Path
+from typing import List, Dict
+from typing import Optional, Union
 
 from .core import VALID_FORMATS
-from .core import soxi
 from .core import sox
+from .core import soxi
+from .log import logger
 
 
-def bitdepth(input_filepath):
+def bitdepth(input_filepath: Union[str, Path]) -> Optional[int]:
     '''
     Number of bits per sample, or None if not applicable.
 
@@ -33,7 +36,7 @@ def bitdepth(input_filepath):
     return int(output)
 
 
-def bitrate(input_filepath):
+def bitrate(input_filepath: Union[str, Path]) -> Optional[float]:
     '''
     Bit rate averaged over the whole file.
     Expressed in bytes per second (bps), or None if not applicable.
@@ -64,7 +67,7 @@ def bitrate(input_filepath):
         return float(output[:-1])
 
 
-def channels(input_filepath):
+def channels(input_filepath: Union[str, Path]) -> int:
     '''
     Show number of channels.
 
@@ -83,7 +86,7 @@ def channels(input_filepath):
     return int(output)
 
 
-def comments(input_filepath):
+def comments(input_filepath: Union[str, Path]) -> str:
     '''
     Show file comments (annotations) if available.
 
@@ -103,7 +106,7 @@ def comments(input_filepath):
     return str(output)
 
 
-def duration(input_filepath):
+def duration(input_filepath: Union[str, Path]) -> Optional[float]:
     '''
     Show duration in seconds, or None if not available.
 
@@ -126,7 +129,7 @@ def duration(input_filepath):
     return float(output)
 
 
-def encoding(input_filepath):
+def encoding(input_filepath: Union[str, Path]) -> str:
     '''
     Show the name of the audio encoding.
 
@@ -145,7 +148,7 @@ def encoding(input_filepath):
     return str(output)
 
 
-def file_type(input_filepath):
+def file_type(input_filepath: Union[str, Path]) -> str:
     '''
     Show detected file-type.
 
@@ -164,13 +167,13 @@ def file_type(input_filepath):
     return str(output)
 
 
-def num_samples(input_filepath):
+def num_samples(input_filepath: Union[str, Path]) -> Optional[int]:
     '''
     Show number of samples, or None if unavailable.
 
     Parameters
     ----------
-    input_filepath : str
+    input_filepath : path-like (str or pathlib.Path)
         Path to audio file.
 
     Returns
@@ -179,6 +182,7 @@ def num_samples(input_filepath):
         total number of samples in audio file.
         Returns None if empty or unavailable.
     '''
+    input_filepath = str(input_filepath)
     validate_input_file(input_filepath)
     output = soxi(input_filepath, 's')
     if output == '0':
@@ -187,7 +191,7 @@ def num_samples(input_filepath):
     return int(output)
 
 
-def sample_rate(input_filepath):
+def sample_rate(input_filepath: Union[str, Path]) -> float:
     '''
     Show sample-rate.
 
@@ -206,7 +210,7 @@ def sample_rate(input_filepath):
     return float(output)
 
 
-def silent(input_filepath, threshold=0.001):
+def silent(input_filepath: Union[str, Path], threshold:float = 0.001) -> bool:
     '''
     Determine if an input file is silent.
 
@@ -234,29 +238,30 @@ def silent(input_filepath, threshold=0.001):
         return True
 
 
-def validate_input_file(input_filepath):
+def validate_input_file(input_filepath: Union[str, Path]) -> None:
     '''Input file validation function. Checks that file exists and can be
     processed by SoX.
 
     Parameters
     ----------
-    input_filepath : str
+    input_filepath : path-like (str or pathlib.Path)
         The input filepath.
 
     '''
-    if not os.path.exists(input_filepath):
-        raise IOError(
-            "input_filepath {} does not exist.".format(input_filepath)
+    input_filepath = Path(input_filepath)
+    if not input_filepath.exists():
+        raise OSError(
+            f"input_filepath {input_filepath} does not exist."
         )
     ext = file_extension(input_filepath)
     if ext not in VALID_FORMATS:
         logger.info("Valid formats: %s", " ".join(VALID_FORMATS))
         logger.warning(
-            "This install of SoX cannot process .{} files.".format(ext)
+            f"This install of SoX cannot process .{ext} files."
         )
 
 
-def validate_input_file_list(input_filepath_list):
+def validate_input_file_list(input_filepath_list: List[Union[str, Path]]) -> None:
     '''Input file list validation function. Checks that object is a list and
     contains valid filepaths that can be processed by SoX.
 
@@ -275,17 +280,21 @@ def validate_input_file_list(input_filepath_list):
         validate_input_file(input_filepath)
 
 
-def validate_output_file(output_filepath):
+def validate_output_file(output_filepath: Union[str, Path]) -> None:
     '''Output file validation function. Checks that file can be written, and
     has a valid file extension. Throws a warning if the path already exists,
     as it will be overwritten on build.
 
     Parameters
     ----------
-    output_filepath : str
+    output_filepath : path-like (str or pathlib.Path)
         The output filepath.
 
     '''
+    # This function enforces use of the path as a string, because
+    # os.access has no analog in pathlib.
+    output_filepath = str(output_filepath)
+
     if output_filepath == '-n':
         return
 
@@ -295,15 +304,15 @@ def validate_output_file(output_filepath):
         not os.access(os.path.dirname(output_filepath), os.W_OK)]
 
     if all(nowrite_conditions):
-        raise IOError(
-            "SoX cannot write to output_filepath {}".format(output_filepath)
+        raise OSError(
+            f"SoX cannot write to output_filepath {output_filepath}"
         )
 
     ext = file_extension(output_filepath)
     if ext not in VALID_FORMATS:
         logger.info("Valid formats: %s", " ".join(VALID_FORMATS))
         logger.warning(
-            "This install of SoX cannot process .{} files.".format(ext)
+            f"This install of SoX cannot process .{ext} files."
         )
 
     if os.path.exists(output_filepath):
@@ -313,12 +322,12 @@ def validate_output_file(output_filepath):
         )
 
 
-def file_extension(filepath):
+def file_extension(filepath: Union[str, Path]) -> str:
     '''Get the extension of a filepath.
 
     Parameters
     ----------
-    filepath : str
+    filepath : path-like (str or pathlib.Path)
         File path.
 
     Returns
@@ -326,10 +335,10 @@ def file_extension(filepath):
     extension : str
         The file's extension
     '''
-    return os.path.splitext(filepath)[1][1:].lower()
+    return Path(filepath).suffix[1:].lower()
 
 
-def info(filepath):
+def info(filepath: Union[str, Path]) -> Dict[str, Union[str, Number]]:
     '''Get a dictionary of file information
 
     Parameters
@@ -363,7 +372,7 @@ def info(filepath):
     return info_dictionary
 
 
-def stat(filepath):
+def stat(filepath: Union[str, Path]) -> Dict[str, Optional[float]]:
     '''Returns a dictionary of audio statistics.
 
     Parameters
@@ -381,7 +390,7 @@ def stat(filepath):
     return stat_dictionary
 
 
-def _stat_call(filepath):
+def _stat_call(filepath: Union[str, Path]) -> str:
     '''Call sox's stat function.
 
     Parameters
@@ -400,7 +409,7 @@ def _stat_call(filepath):
     return stat_output
 
 
-def _parse_stat(stat_output):
+def _parse_stat(stat_output: str) -> Dict[str, Optional[float]]:
     '''Parse the string output from sox's stat function
 
     Parameters
