@@ -1,5 +1,6 @@
-import unittest
+from pathlib import Path
 import os
+import unittest
 
 from sox import file_info
 from sox.core import SoxError
@@ -19,6 +20,32 @@ OUTPUT_FILE = relpath('data/output.wav')
 SILENT_FILE = relpath('data/silence.wav')
 
 
+class TestCarriageReturnStrip(unittest.TestCase):
+
+    def test_carriage_return_strip(self):
+        def part_of_file_info_bitrate(output):
+            # The characters below stand for kilo, Mega, Giga, etc.
+            greek_prefixes = '\0kMGTPEZY'
+            # Don't need the 'if output == "0":' branch here
+            if output[-1] in greek_prefixes:
+                multiplier = 1000.0**(greek_prefixes.index(output[-1]))
+                return float(output[:-1])*multiplier
+            else:
+                return float(output[:-1])
+        # Simulate a shell output with carriage return
+        shell_output = '256k\n\r'
+        # When only '\n' is stripped
+        output = shell_output.strip('\n')
+        with self.assertRaises(ValueError):
+            part_of_file_info_bitrate(output)
+        # When '\n\r' is stripped
+        output = shell_output.strip('\n\r')
+        actual = part_of_file_info_bitrate(output)
+        expected = 256000.0
+        self.assertIsInstance(actual, float)
+        self.assertEqual(expected, actual)
+
+
 class TestBitrate(unittest.TestCase):
 
     def test_wav(self):
@@ -26,6 +53,11 @@ class TestBitrate(unittest.TestCase):
         expected = 706000.0
         self.assertEqual(expected, actual)
 
+    def test_wav_pathlib(self):
+        actual = file_info.bitrate(Path(INPUT_FILE))
+        expected = 706000.0
+        self.assertEqual(expected, actual)
+
     def test_aiff(self):
         actual = file_info.bitrate(INPUT_FILE2)
         expected = 768000.0
@@ -36,6 +68,8 @@ class TestBitrate(unittest.TestCase):
         expected = None
         self.assertEqual(expected, actual)
 
+
+
 class TestBitdepth(unittest.TestCase):
 
     def test_wav(self):
@@ -43,6 +77,11 @@ class TestBitdepth(unittest.TestCase):
         expected = 16
         self.assertEqual(expected, actual)
 
+    def test_wav_pathlib(self):
+        actual = file_info.bitdepth(Path(INPUT_FILE))
+        expected = 16
+        self.assertEqual(expected, actual)
+
     def test_aiff(self):
         actual = file_info.bitdepth(INPUT_FILE2)
         expected = 32
@@ -66,6 +105,11 @@ class TestChannels(unittest.TestCase):
         expected = 1
         self.assertEqual(expected, actual)
 
+    def test_wav_pathlib(self):
+        actual = file_info.channels(Path(INPUT_FILE))
+        expected = 1
+        self.assertEqual(expected, actual)
+
     def test_aiff(self):
         actual = file_info.channels(INPUT_FILE2)
         expected = 3
@@ -84,6 +128,11 @@ class TestComments(unittest.TestCase):
         expected = ""
         self.assertEqual(expected, actual)
 
+    def test_wav_pathlib(self):
+        actual = file_info.comments(Path(INPUT_FILE))
+        expected = ""
+        self.assertEqual(expected, actual)
+
     def test_aiff(self):
         actual = file_info.comments(INPUT_FILE2)
         expected = "Processed by SoX"
@@ -102,6 +151,11 @@ class TestDuration(unittest.TestCase):
         expected = 10.0
         self.assertEqual(expected, actual)
 
+    def test_wav_pathlib(self):
+        actual = file_info.duration(Path(INPUT_FILE))
+        expected = 10.0
+        self.assertEqual(expected, actual)
+
     def test_spacey_wav(self):
         actual = file_info.duration(SPACEY_FILE)
         expected = 10.0
@@ -125,6 +179,11 @@ class TestEncoding(unittest.TestCase):
         expected = "Signed Integer PCM"
         self.assertEqual(expected, actual)
 
+    def test_wav_pathlib(self):
+        actual = file_info.encoding(Path(INPUT_FILE))
+        expected = "Signed Integer PCM"
+        self.assertEqual(expected, actual)
+
     def test_aiff(self):
         actual = file_info.encoding(INPUT_FILE2)
         expected = "Signed Integer PCM"
@@ -143,6 +202,11 @@ class TestFileType(unittest.TestCase):
         expected = "wav"
         self.assertEqual(expected, actual)
 
+    def test_wav_pathlib(self):
+        actual = file_info.file_type(Path(INPUT_FILE))
+        expected = "wav"
+        self.assertEqual(expected, actual)
+
     def test_aiff(self):
         actual = file_info.file_type(INPUT_FILE2)
         expected = "aiff"
@@ -161,6 +225,11 @@ class TestNumSamples(unittest.TestCase):
         expected = 441000
         self.assertEqual(expected, actual)
 
+    def test_wav_pathlib(self):
+        actual = file_info.num_samples(Path(INPUT_FILE))
+        expected = 441000
+        self.assertEqual(expected, actual)
+
     def test_aiff(self):
         actual = file_info.num_samples(INPUT_FILE2)
         expected = 80000
@@ -179,6 +248,11 @@ class TestSampleRate(unittest.TestCase):
         expected = 44100
         self.assertEqual(expected, actual)
 
+    def test_wav_pathlib(self):
+        actual = file_info.sample_rate(Path(INPUT_FILE))
+        expected = 44100
+        self.assertEqual(expected, actual)
+
     def test_aiff(self):
         actual = file_info.sample_rate(INPUT_FILE2)
         expected = 8000
@@ -197,6 +271,11 @@ class TestSilent(unittest.TestCase):
         expected = False
         self.assertEqual(expected, actual)
 
+    def test_nonsilent_pathlib(self):
+        actual = file_info.silent(Path(INPUT_FILE))
+        expected = False
+        self.assertEqual(expected, actual)
+
     def test_silent(self):
         actual = file_info.silent(SILENT_FILE)
         expected = True
@@ -215,6 +294,11 @@ class TestFileExtension(unittest.TestCase):
         expected = 'xyz'
         self.assertEqual(expected, actual)
 
+    def test_ext1_pathlib(self):
+        actual = file_info.file_extension(Path('simplefile.xyz'))
+        expected = 'xyz'
+        self.assertEqual(expected, actual)
+
     def test_ext2(self):
         actual = file_info.file_extension('less.simple.file.xyz')
         expected = 'xyz'
@@ -244,18 +328,22 @@ class TestFileExtension(unittest.TestCase):
 class TestInfo(unittest.TestCase):
 
     def test_dictionary(self):
-        actual = file_info.info(INPUT_FILE)
-        expected = {
-            'channels': 1,
-            'sample_rate': 44100.0,
-            'bitdepth': 16,
-            'bitrate': 706000.0,
-            'duration': 10.0,
-            'num_samples': 441000,
-            'encoding': 'Signed Integer PCM',
-            'silent': False
-        }
-        self.assertEqual(expected, actual)
+        for use_pathlib in [False, True]:
+            with self.subTest():
+                input_file = Path(INPUT_FILE) if use_pathlib else INPUT_FILE
+
+                actual = file_info.info(input_file)
+                expected = {
+                    'channels': 1,
+                    'sample_rate': 44100.0,
+                    'bitdepth': 16,
+                    'bitrate': 706000.0,
+                    'duration': 10.0,
+                    'num_samples': 441000,
+                    'encoding': 'Signed Integer PCM',
+                    'silent': False
+                }
+                self.assertEqual(expected, actual)
 
 
 class TestValidateInputFile(unittest.TestCase):
@@ -265,6 +353,11 @@ class TestValidateInputFile(unittest.TestCase):
         expected = None
         self.assertEqual(expected, actual)
 
+    def test_valid_pathlib(self):
+        actual = file_info.validate_input_file(Path(INPUT_FILE))
+        expected = None
+        self.assertEqual(expected, actual)
+
     def test_valid_wspaces(self):
         actual = file_info.validate_input_file(SPACEY_FILE)
         expected = None
